==> wordpress_0.5.4.orig.tar.gz: wordpress-0.5.4.orig/src/WPHomeScreenInfo.cpp <==

#include <QSvgWidget>
#include <QPixmap>

#include "commentsview.h"
#include "WPHomeScreenInfo.h"
#include "WPData.h"

#ifdef Q_WS_MAEMO_5
static const int KItemDefaultHeight = 145;
static const int KLogoDefaultSize = 115;
#else
static const int KItemDefaultHeight = 93;
static const int KLogoDefaultSize = 75;
#endif

WPHomeScreenInfo::WPHomeScreenInfo(CommentsView& aParent) : QFrame(&aParent), iParent(aParent)
{
	ui.setupUi(this);

	QSvgWidget *svg = new QSvgWidget(":/images/wp-logo.svg", this);
	svg->setFixedSize(KLogoDefaultSize, KLogoDefaultSize);
	ui.logoLayout->addWidget(svg);
	setFixedHeight(KItemDefaultHeight);
}

WPHomeScreenInfo::~WPHomeScreenInfo()
{
}

void WPHomeScreenInfo::UpdateData(const WPDataBlog *aData)
{
	WPDataPost post;
	WPDataComment comment;
	const int comments = aData->iComments.size();
	int unapproved = 0;
	foreach (comment, aData->iComments)
	{
		if (comment.iStatus == "hold")
			unapproved++;
	}

	ui.blogName->setText(aData->iBlogName);
	ui.statsLabel->setText(QString::number(unapproved)
						   + tr(" unapproved comments\n")
						   + QString::number(comments)
						   + tr(" comments in ")
						   + QString::number(aData->iPosts.size())
						   + tr(" posts"));
}

void WPHomeScreenInfo::resizeEvent(QResizeEvent* aEvent)
{
    // Set max size for the clipping label -- otherwise it
	// will start maximized and decrease in small steps
	// WP logo = 75
    // Padding on both sides = 4
    const int modifier = 75 + 4;
	const int width = iParent.VisibleSize().width() - modifier;
	ui.blogName->setMaximumWidth(width);
	QFrame::resizeEvent(aEvent);
}

==> wordpress_0.5.5.orig.tar.gz: wordpress-0.5.5.orig/src/WPHomeScreenInfo.cpp <==

#include <QSvgWidget>
#include <QPixmap>

#include "commentsview.h"
#include "WPHomeScreenInfo.h"
#include "WPData.h"

#ifdef Q_OS_SYMBIAN
static const int KItemDefaultHeight = 123;
static const int KLogoDefaultSize = 75;
#else
static const int KItemDefaultHeight = 170;
static const int KLogoDefaultSize = 115;
#endif

WPHomeScreenInfo::WPHomeScreenInfo(CommentsView& aParent) : QFrame(&aParent), iParent(aParent)
{
	ui.setupUi(this);

	QSvgWidget *svg = new QSvgWidget(":/images/wp-logo.svg", this);
	svg->setFixedSize(KLogoDefaultSize, KLogoDefaultSize);
	ui.logoLayout->addWidget(svg);
	setFixedHeight(KItemDefaultHeight);
}

WPHomeScreenInfo::~WPHomeScreenInfo()
{
}

void WPHomeScreenInfo::UpdateData(const WPDataBlog *aData)
{
	WPDataPost post;
	WPDataComment comment;
	const int comments = aData->iComments.size();
	int unapproved = 0;
	foreach (comment, aData->iComments)
	{
		if (comment.iStatus == "hold")
			unapproved++;
	}

        QString statsText = "";
        statsText += tr("%1 unapproved comments").arg(unapproved) + "\n";
        statsText += tr("%1 comments in %2 posts").arg(comments).arg(aData->iPosts.size()) + "\n";
        if (aData->iApiKey != "") {
            statsText += tr("%1 visits in last 365 days").arg(aData->iStats.iTotalVisits);
        }

	ui.blogName->setText(aData->iBlogName);
        ui.statsLabel->setText(statsText);
}

void WPHomeScreenInfo::resizeEvent(QResizeEvent* aEvent)
{
    // Set max size for the clipping label -- otherwise it
	// will start maximized and decrease in small steps
	// WP logo = 75
    // Padding on both sides = 4
    const int modifier = 75 + 4;
	const int width = iParent.VisibleSize().width() - modifier;
	ui.blogName->setMaximumWidth(width);
	QFrame::resizeEvent(aEvent);
}
